0.1.1
=====
- Fixed issue in `MANIFEST.in` which excluded the `requirements.txt` files.


0.1.0
=====
- Initial release
- Added unit tests
- Support for `ndb_json.dump`, `ndb_json.dumps`, and `ndb_json.loads`
